@@ -165,7 +165,7 @@ class LoadMaster(HttpClient):
 
     def stats(self):
         response = self._get('/stats')
-        send_response(response)
+        return send_response(response)
 
     def update_firmware(self, file):
         response = self._post('/installpatch', file)
@@ -181,12 +181,12 @@ class LoadMaster(HttpClient):
 
     def get_sdn_controller(self):
         response = self._get('/getsdncontroller')
-        send_response(response)
+        return send_response(response)
 
     def get_license_info(self):
         try:
             response = self._get('360/licenseinfo')
-            send_response(response)
+            return send_response(response)
 
         except KempTechApiException:
             raise CommandNotAvailableException(
@@ -194,20 +194,20 @@ class LoadMaster(HttpClient):
 
     def list_addons(self):
         response = self._get('/listaddon')
-        send_response(response)
+        return send_response(response)
 
     def upload_template(self, file):
         response = self._post('/uploadtemplate', file)
-        send_response(response)
+        return send_response(response)
 
     def list_templates(self):
         response = self._get('/listtemplates')
-        send_response(response)
+        return send_response(response)
 
     def delete_template(self, template_name):
         params = {'name': template_name}
         response = self._get('/deltemplate', parameters=params)
-        send_response(response)
+        return send_response(response)
 
     def apply_template(self, virtual_ip, port, protocol, template_name):
         params = {
@@ -217,11 +217,11 @@ class LoadMaster(HttpClient):
             'name': template_name,
         }
         response = self._get('/addvs', parameters=params)
-        send_response(response)
+        return send_response(response)
 
     def get_sdn_info(self):
         response = self._get('/sdninfo')
-        send_response(response)
+        return send_response(response)
 
     def restore_backup(self, backup_type, file):
         # 1 LoadMaster Base Configuration
@@ -232,7 +232,7 @@ class LoadMaster(HttpClient):
         params = {"type": backup_type}
         response = self._post('/restore', file=file,
                               parameters=params)
-        send_response(response)
+        return send_response(response)
 
     def backup(self):
         # Dirty API, dirty hack.
@@ -252,9 +252,9 @@ class LoadMaster(HttpClient):
             "password": password,
         }
         response = self._get('/alsilicense', parameters=params)
-        send_response(response)
+        return send_response(response)
 
     def set_initial_password(self, password):
         params = {"passwd": password}
         response = self._get('/set_initial_password', parameters=params)
-        send_response(response)
+        return send_response(response)
